@@ -29,23 +29,10 @@ try:
     from ..path.exchange.load import load_path, path_formats
 except BaseException as E:
     # save a traceback to see why path didn't import
-    _path_exception = E
-
-    def load_path(*args, **kwargs):
-        """
-        Dummy load path function that will raise an exception
-        on use. Import of path failed, probably because a
-        dependency is not installed.
-
-        Raises
-        ----------
-        path_exception : BaseException
-          Whatever failed when we imported path
-        """
-        raise _path_exception
-
-    def path_formats():
-        return []
+    from ..exceptions import closure
+    load_path = closure(E)
+    # no path formats available
+    def path_formats(): return []
 
 
 def mesh_formats():
@@ -80,6 +67,7 @@ def available_formats():
 def load(file_obj,
          file_type=None,
          resolver=None,
+         force=None,
          **kwargs):
     """
     Load a mesh or vectorized path into objects like
@@ -93,6 +81,9 @@ def load(file_obj,
       What kind of file type do we have (eg: 'stl')
     resolver : trimesh.visual.Resolver
       Object to load referenced assets like materials and textures
+    force : None or str
+      For 'mesh': try to coerce scenes into a single mesh
+      For 'scene': try to coerce everything into a scene
     kwargs : dict
       Passed to geometry __init__
 
@@ -167,6 +158,12 @@ def load(file_obj,
     if opened:
         file_obj.close()
 
+    # combine a scene into a single mesh
+    if force == 'mesh' and isinstance(loaded, Scene):
+        return util.concatenate(loaded.dump())
+    if force == 'scene' and not isinstance(loaded, Scene):
+        return Scene(loaded)
+
     return loaded
 
 
@@ -349,6 +346,11 @@ def load_remote(url, **kwargs):
     url : string
       URL containing mesh file
     **kwargs : passed to `load`
+
+    Returns
+    ------------
+    loaded : Trimesh, Path, Scene
+      Loaded result
     """
     # import here to keep requirement soft
     import requests
@@ -361,9 +363,21 @@ def load_remote(url, **kwargs):
     # so loaders can access textures/etc
     resolver = resolvers.WebResolver(url)
 
-    # actually load
+    try:
+        # if we have a bunch of query parameters the type
+        # will be wrong so try to clean up the URL
+        # urllib is Python 3 only
+        import urllib
+        # remove the url-safe encoding then split off query params
+        file_type = urllib.parse.unquote(
+            url).split('?', 1)[0].split('/')[-1].strip()
+    except BaseException:
+        # otherwise just use the last chunk of URL
+        file_type = url.split('/')[-1].split('?', 1)[0]
+
+    # actually load the data from the retrieved bytes
     loaded = load(file_obj=file_obj,
-                  file_type=url,
+                  file_type=file_type,
                   resolver=resolver,
                   **kwargs)
     return loaded
@@ -375,21 +389,28 @@ def load_kwargs(*args, **kwargs):
     """
     def handle_scene():
         """
-        Load a scene from our kwargs:
+        Load a scene from our kwargs.
 
         class:      Scene
         geometry:   dict, name: Trimesh kwargs
         graph:      list of dict, kwargs for scene.graph.update
         base_frame: str, base frame of graph
         """
-        scene = Scene()
-        scene.geometry.update({k: load_kwargs(v) for
-                               k, v in kwargs['geometry'].items()})
-        for k in kwargs['graph']:
-            if isinstance(k, dict):
-                scene.graph.update(**k)
-            elif util.is_sequence(k) and len(k) == 3:
-                scene.graph.update(k[1], k[0], **k[2])
+        graph = kwargs.get('graph', None)
+        geometry = {k: load_kwargs(v) for
+                    k, v in kwargs['geometry'].items()}
+
+        if graph is not None:
+            scene = Scene()
+            scene.geometry.update(geometry)
+            for k in graph:
+                if isinstance(k, dict):
+                    scene.graph.update(**k)
+                elif util.is_sequence(k) and len(k) == 3:
+                    scene.graph.update(k[1], k[0], **k[2])
+        else:
+            scene = Scene(geometry)
+
         if 'base_frame' in kwargs:
             scene.graph.base_frame = kwargs['base_frame']
         if 'metadata' in kwargs:
@@ -418,6 +439,18 @@ def load_kwargs(*args, **kwargs):
                                     file_type=file_type)
         return Trimesh(**k)
 
+    def handle_path():
+        from ..path import Path2D, Path3D
+        e, v = kwargs['entities'], kwargs['vertices']
+        if 'metadata' in kwargs:
+            m = kwargs['metadata']
+        else:
+            m = None
+        if v.shape[1] == 2:
+            return Path2D(entities=e, vertices=v, metadata=m)
+        elif v.shape[1] == 3:
+            return Path3D(entities=e, vertices=v, metadata=m)
+
     def handle_pointcloud():
         return PointCloud(**kwargs)
 
@@ -431,14 +464,14 @@ def load_kwargs(*args, **kwargs):
     # (function, tuple of expected keys)
     # order is important
     handlers = (
-        (handle_scene, ('graph', 'geometry')),
+        (handle_scene, ('geometry',)),
         (handle_mesh, ('vertices', 'faces')),
+        (handle_path, ('entities', 'vertices')),
         (handle_pointcloud, ('vertices',)),
         (handle_export, ('file_type', 'data')))
 
     # filter out keys with a value of None
     kwargs = {k: v for k, v in kwargs.items() if v is not None}
-
     # loop through handler functions and expected key
     for func, expected in handlers:
         if all(i in kwargs for i in expected):
@@ -447,7 +480,7 @@ def load_kwargs(*args, **kwargs):
             # exit the loop as we found one
             break
     else:
-        raise ValueError('unable to determine type!')
+        raise ValueError('unable to determine type: {}'.format(kwargs.keys()))
 
     return handler()
 
