@@ -23,6 +23,8 @@ def load_obj(file_obj,
              resolver=None,
              split_object=False,
              group_material=True,
+             skip_materials=False,
+             maintain_order=False,
              **kwargs):
     """
     Load a Wavefront OBJ file into kwargs for a trimesh.Scene
@@ -40,6 +42,11 @@ def load_obj(file_obj,
     group_material : bool
       Group faces that share the same material
       into the same mesh.
+    skip_materials : bool
+      Don't load any materials.
+    maintain_order : bool or None
+      Do not reorder faces or vertices which may result
+      in visual artifacts.
 
     Returns
     -------------
@@ -47,7 +54,6 @@ def load_obj(file_obj,
       Keyword arguments which can be loaded by
       trimesh.exchange.load.load_kwargs into a trimesh.Scene
     """
-
     # get text as bytes or string blob
     text = file_obj.read()
 
@@ -61,7 +67,7 @@ def load_obj(file_obj,
     # Load Materials
     materials = {}
     mtl_position = text.find('mtllib')
-    if mtl_position >= 0:
+    if not skip_materials and mtl_position >= 0:
         # take the line of the material file after `mtllib`
         # which should be the file location of the .mtl file
         mtl_path = text[mtl_position + 6:text.find('\n', mtl_position)].strip()
@@ -140,7 +146,7 @@ def load_obj(file_obj,
             # i.e. something like:
             #  '31407 31406 31408',
             #  '32303/2469 32304/2469 32305/2469',
-            log.warning('faces have mixed data, using slow fallback!')
+            log.debug('faces have mixed data, using slow fallback!')
             faces, faces_tex, faces_norm = _parse_faces_fallback(face_lines)
 
         # TODO: name usually falls back to something useless
@@ -156,10 +162,12 @@ def load_obj(file_obj,
             # where each face
             if faces_norm is not None and len(faces_norm) == len(faces):
                 new_faces, mask_v, mask_vt, mask_vn = unmerge_faces(
-                    faces, faces_tex, faces_norm)
+                    faces, faces_tex, faces_norm, maintain_faces=maintain_order)
             else:
                 mask_vn = None
-                new_faces, mask_v, mask_vt = unmerge_faces(faces, faces_tex)
+                # no face normals but face texturre
+                new_faces, mask_v, mask_vt = unmerge_faces(
+                    faces, faces_tex, maintain_faces=maintain_order)
 
             if tol.strict:
                 # we should NOT have messed up the faces
@@ -172,9 +180,9 @@ def load_obj(file_obj,
                 # survive index errors as sometimes we
                 # want materials without UV coordinates
                 uv = vt[mask_vt]
-            except BaseException as E:
+            except BaseException:
+                log.warning('index failed on UV coordinates, skipping!')
                 uv = None
-                raise E
 
             # mask vertices and use new faces
             mesh.update({'vertices': v[mask_v].copy(),
@@ -191,7 +199,7 @@ def load_obj(file_obj,
             if vn is not None and np.shape(faces_norm) == faces.shape:
                 # do the crazy unmerging logic for split indices
                 new_faces, mask_v, mask_vn = unmerge_faces(
-                    faces, faces_norm)
+                    faces, faces_norm, maintain_faces=maintain_order)
             else:
                 # generate the mask so we only include
                 # referenced vertices in every new mesh
@@ -808,9 +816,12 @@ def export_obj(mesh,
                 col_delim=' ',
                 row_delim='\nvt ',
                 digits=digits))
+            material = mesh.visual.material
+            if hasattr(material, 'to_simple'):
+                material = material.to_simple()
             (tex_data,
              tex_name,
-             mtl_name) = mesh.visual.material.to_obj()
+             mtl_name) = material.to_obj()
             # add the reference to the MTL file
             objects.appendleft('mtllib {}'.format(mtl_name))
             # add the directive to use the exported material
