@@ -1131,10 +1131,15 @@ def array_to_string(array,
         raise ValueError('conversion only works on 1D/2D arrays not %s!',
                          str(array.shape))
 
-    # allow a value to be repeated in a value format
-    repeats = value_format.count('{}')
+    # abort for structured arrays
+    if array.dtype.names is not None:
+        raise ValueError(
+            'array is  structured, use structured_array_to_string instead')
 
-    if array.dtype.kind == 'i':
+    # allow a value to be repeated in a value format
+    repeats = value_format.count('{')
+
+    if array.dtype.kind in ['i', 'u']:
         # integer types don't need a specified precision
         format_str = value_format + col_delim
     elif array.dtype.kind == 'f':
@@ -1168,6 +1173,96 @@ def array_to_string(array,
     return formatted
 
 
+def structured_array_to_string(array,
+                               col_delim=' ',
+                               row_delim='\n',
+                               digits=8,
+                               value_format='{}'):
+    """
+    Convert an unstructured array into a string with a specified
+    number of digits and delimiter. The reason thisexists is
+    that the basic numpy array to string conversionsare
+    surprisingly bad.
+
+    Parameters
+    ------------
+    array : (n,) or (n, d) float or int
+       Data to be converted
+       If shape is (n,) only column delimiter will be used
+    col_delim : str
+      What string should separate values in a column
+    row_delim : str
+      What string should separate values in a row
+    digits : int
+      How many digits should floating point numbers include
+    value_format : str
+       Format string for each value or sequence of values
+       If multiple values per value_format it must divide
+       into array evenly.
+
+    Returns
+    ----------
+    formatted : str
+       String representation of original array
+    """
+    # convert inputs to correct types
+    array = np.asanyarray(array)
+    digits = int(digits)
+    row_delim = str(row_delim)
+    col_delim = str(col_delim)
+    value_format = str(value_format)
+
+    # abort for non-flat arrays
+    if len(array.shape) > 1:
+        raise ValueError('conversion only works on 1D/2D arrays not %s!',
+                         str(array.shape))
+
+    # abort for unstructured arrays
+    if array.dtype.names is None:
+        raise ValueError('array is not structured, use array_to_string instead')
+
+    # do not allow a value to be repeated in a value format
+    if value_format.count('{') > 1:
+        raise ValueError(
+            'value_format %s is invalid, repeating unstructured array '
+            + 'values is unsupported', value_format)
+
+    format_str = ''
+    for name in array.dtype.names:
+        kind = array[name].dtype.kind
+        element_row_length = (
+            array[name].shape[1] if len(array[name].shape) == 2 else 1)
+        if kind in ['i', 'u']:
+            # integer types need a no-decimal formatting
+            element_format_str = value_format.replace(
+                '{}', '{:0.0f}') + col_delim
+        elif kind == 'f':
+            # add the digits formatting to floats
+            element_format_str = value_format.replace(
+                '{}', '{:.' + str(digits) + 'f}') + col_delim
+        else:
+            raise ValueError('dtype %s not convertible!',
+                             array.dtype)
+        format_str += element_row_length * element_format_str
+
+    # length of extra delimiters at the end
+    format_str = format_str[:-len(col_delim)] + row_delim
+    # expand format string to whole array
+    format_str *= len(array)
+
+    # loop through flat fields and flatten to single array
+    count = len(array)
+    # will upgrade everything to a float
+    flattened = np.hstack(
+        [array[k].reshape((count, -1))
+         for k in array.dtype.names]).reshape(-1)
+
+    # run the format operation and remove the extra delimiters
+    formatted = format_str.format(*flattened)[:-len(row_delim)]
+
+    return formatted
+
+
 def array_to_encoded(array, dtype=None, encoding='base64'):
     """
     Export a numpy array to a compact serializable dictionary.
@@ -1411,6 +1506,10 @@ def concatenate(a, b=None):
     # stack meshes into flat list
     meshes = np.append(a, b)
 
+    # if there is only one mesh just return the first
+    if len(meshes) == 1:
+        return meshes[0].copy()
+
     # extract the trimesh type to avoid a circular import
     # and assert that both inputs are Trimesh objects
     trimesh_type = type_named(meshes[0], 'Trimesh')
@@ -1423,16 +1522,16 @@ def concatenate(a, b=None):
     # only save face normals if already calculated
     face_normals = None
     if all('face_normals' in m._cache for m in meshes):
-        face_normals = np.vstack([m.face_normals
-                                  for m in meshes])
+        face_normals = np.vstack(
+            [m.face_normals for m in meshes])
 
     try:
         # concatenate visuals
         visual = meshes[0].visual.concatenate(
             [m.visual for m in meshes[1:]])
     except BaseException:
-        log.warning('failed to combine visuals',
-                    exc_info=True)
+        log.debug(
+            'failed to combine visuals', exc_info=True)
         visual = None
     # create the mesh object
     mesh = trimesh_type(vertices=vertices,
@@ -1603,7 +1702,6 @@ def jsonify(obj, **kwargs):
       JSON dump of obj
     """
     class NumpyEncoder(json.JSONEncoder):
-
         def default(self, obj):
             # will work for numpy.ndarrays
             # as well as their int64/etc objects
@@ -1644,6 +1742,14 @@ def convert_like(item, like):
             isinstance(item[0], like.__class__)):
         return item[0]
 
+    if (isinstance(item, str) and
+        like.__class__.__name__ == 'Polygon' and
+            item.startswith('POLYGON')):
+        # break our rule on imports but only a little bit
+        # the import was a WKT serialized polygon
+        from shapely import wkt
+        return wkt.loads(item)
+
     # otherwise just run the conversion
     item = like.__class__(item)
 
@@ -2275,7 +2381,7 @@ def decode_text(text, initial='utf-8'):
                 initial,
                 detect['encoding'],
                 detect['confidence']))
-        # try to decode again, unwrapped in try
+        # try to decode again, unwrap in try
         text = text.decode(detect['encoding'])
     return text
 
